@@ -109,7 +109,10 @@ IPv4Widget::IPv4Widget(const NetworkManager::Setting::Ptr &setting, QWidget* par
 
     connect(m_ui->btnRoutes, &QPushButton::clicked, this, &IPv4Widget::slotRoutesDialog);
 
-    // Validation
+    // Connect for setting check
+    watchChangedSetting();
+
+    // Connect for validity check
     connect(m_ui->dns, &KLineEdit::textChanged, this, &IPv4Widget::slotWidgetChanged);
     connect(m_ui->method, static_cast<void (KComboBox::*)(int)>(&KComboBox::currentIndexChanged), this, &IPv4Widget::slotWidgetChanged);
     connect(&d->model, &QStandardItemModel::dataChanged, this, &IPv4Widget::slotWidgetChanged);
@@ -265,9 +268,8 @@ void IPv4Widget::slotModeComboChanged(int index)
         m_ui->ipv4RequiredCB->setEnabled(true);
         m_ui->btnRoutes->setEnabled(true);
         m_ui->tableViewAddresses->setEnabled(false);
-        m_ui->tableViewAddresses->setVisible(false);
-        m_ui->btnAdd->setVisible(false);
-        m_ui->btnRemove->setVisible(false);
+        m_ui->btnAdd->setEnabled(false);
+        m_ui->btnRemove->setEnabled(false);
     } else if (index == AutomaticOnlyIP) {
         m_ui->dnsLabel->setText(i18n("DNS Servers:"));
         m_ui->dns->setEnabled(true);
@@ -278,9 +280,8 @@ void IPv4Widget::slotModeComboChanged(int index)
         m_ui->ipv4RequiredCB->setEnabled(true);
         m_ui->btnRoutes->setEnabled(true);
         m_ui->tableViewAddresses->setEnabled(false);
-        m_ui->tableViewAddresses->setVisible(false);
-        m_ui->btnAdd->setVisible(false);
-        m_ui->btnRemove->setVisible(false);
+        m_ui->btnAdd->setEnabled(false);
+        m_ui->btnRemove->setEnabled(false);
     } else if (index == Manual) {  // Manual
         m_ui->dnsLabel->setText(i18n("DNS Servers:"));
         m_ui->dns->setEnabled(true);
@@ -291,9 +292,8 @@ void IPv4Widget::slotModeComboChanged(int index)
         m_ui->ipv4RequiredCB->setEnabled(true);
         m_ui->btnRoutes->setEnabled(true);
         m_ui->tableViewAddresses->setEnabled(true);
-        m_ui->tableViewAddresses->setVisible(true);
-        m_ui->btnAdd->setVisible(true);
-        m_ui->btnRemove->setVisible(true);
+        m_ui->btnAdd->setEnabled(true);
+        m_ui->btnRemove->setEnabled(true);
     } else if (index == LinkLocal || index == Shared) {  // Link-local or Shared
         m_ui->dnsLabel->setText(i18n("DNS Servers:"));
         m_ui->dns->setEnabled(false);
@@ -304,9 +304,8 @@ void IPv4Widget::slotModeComboChanged(int index)
         m_ui->ipv4RequiredCB->setEnabled(true);
         m_ui->btnRoutes->setEnabled(false);
         m_ui->tableViewAddresses->setEnabled(false);
-        m_ui->tableViewAddresses->setVisible(false);
-        m_ui->btnAdd->setVisible(false);
-        m_ui->btnRemove->setVisible(false);
+        m_ui->btnAdd->setEnabled(false);
+        m_ui->btnRemove->setEnabled(false);
     } else if (index == Disabled) {  // Disabled
         m_ui->dnsLabel->setText(i18n("DNS Servers:"));
         m_ui->dns->setEnabled(false);
@@ -317,9 +316,8 @@ void IPv4Widget::slotModeComboChanged(int index)
         m_ui->ipv4RequiredCB->setEnabled(false);
         m_ui->btnRoutes->setEnabled(false);
         m_ui->tableViewAddresses->setEnabled(false);
-        m_ui->tableViewAddresses->setVisible(false);
-        m_ui->btnAdd->setVisible(false);
-        m_ui->btnRemove->setVisible(false);
+        m_ui->btnAdd->setEnabled(false);
+        m_ui->btnRemove->setEnabled(false);
     }
 }
 
