@@ -394,13 +394,6 @@ void Handler::enableWwan(bool enable)
     NetworkManager::setWwanEnabled(enable);
 }
 
-// void Handler::editConnection(const QString& uuid)
-// {
-//     QStringList args;
-//     args << uuid;
-//     KProcess::startDetached("kde5-nm-connection-editor", args);
-// }
-
 void Handler::removeConnection(const QString& connection)
 {
     NetworkManager::Connection::Ptr con = NetworkManager::findConnection(connection);
@@ -434,11 +427,6 @@ void Handler::updateConnection(const NetworkManager::Connection::Ptr& connection
     connect(watcher, &QDBusPendingCallWatcher::finished, this, &Handler::replyFinished);
 }
 
-void Handler::openEditor()
-{
-    KProcess::startDetached("kde5-nm-connection-editor");
-}
-
 void Handler::requestScan()
 {
     Q_FOREACH (NetworkManager::Device::Ptr device, NetworkManager::networkInterfaces()) {
